@@ -5,13 +5,13 @@ import sys
 
 def _print_output(output):
     if hasattr(output, 'stdout') and output.stdout:
-        print(output.stdout)
+        print(output.stdout, flush=True)
 
     if hasattr(output, 'stderr') and output.stderr:
         print(colored(output.stderr, "red"), file=sys.stderr)
 
     if isinstance(output, Exception):
-        print(output)
+        print(output, flush=True)
 
 
 def ss(
